# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: road_network.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
  name='road_network.proto',
  package='l5kit.maps',
  syntax='proto3',
  serialized_options=b'Z\004maps',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12road_network.proto\x12\nl5kit.maps\x1a google/protobuf/descriptor.proto\x1a\x1bgoogle/protobuf/empty.proto\"\x16\n\x08GlobalId\x12\n\n\x02id\x18\x01 \x01(\x0c\"P\n\x0bGeoLocation\x12\x0e\n\x06lat_e7\x18\x01 \x01(\x0f\x12\x0e\n\x06lng_e7\x18\x02 \x01(\x0f\x12\x15\n\x0b\x61ltitude_cm\x18\x03 \x01(\x11H\x00\x42\n\n\x08\x41ltitude\"L\n\x08GeoFrame\x12\'\n\x06origin\x18\x01 \x01(\x0b\x32\x17.l5kit.maps.GeoLocation\x12\x17\n\x0f\x62\x65\x61ring_degrees\x18\x02 \x01(\x02\"7\n\x0fLocalizedString\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xa2\x01\n\x0fRoadNetworkNode\x12)\n\x08location\x18\x01 \x01(\x0b\x32\x17.l5kit.maps.GeoLocation\x12+\n\rroad_segments\x18\x02 \x03(\x0b\x32\x14.l5kit.maps.GlobalId\x12\x0f\n\x07z_level\x18\x03 \x01(\x11\x12&\n\x08junction\x18\x04 \x01(\x0b\x32\x14.l5kit.maps.GlobalId\"\xa8\x01\n\x11\x41\x63\x63\x65ssRestriction\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\".l5kit.maps.AccessRestriction.Type\"a\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0eNO_RESTRICTION\x10\x01\x12\x0c\n\x08ONLY_HOV\x10\x02\x12\x0c\n\x08ONLY_BUS\x10\x03\x12\r\n\tONLY_BIKE\x10\x04\x12\r\n\tONLY_TURN\x10\x05\"\xad\x02\n\x11\x44\x61ilyTimeInterval\x12\x43\n\x0f\x64\x61y_of_the_week\x18\x01 \x01(\x0e\x32*.l5kit.maps.DailyTimeInterval.DayOfTheWeek\x12 \n\x18start_local_time_seconds\x18\x02 \x01(\x05\x12\x1e\n\x16\x65nd_local_time_seconds\x18\x03 \x01(\x05\x12%\n\x1dtimezone_database_region_name\x18\x04 \x01(\t\"j\n\x0c\x44\x61yOfTheWeek\x12\n\n\x06SUNDAY\x10\x00\x12\n\n\x06MONDAY\x10\x01\x12\x0b\n\x07TUESDAY\x10\x02\x12\r\n\tWEDNESDAY\x10\x03\x12\x0c\n\x08THURSDAY\x10\x04\x12\n\n\x06\x46RIDAY\x10\x05\x12\x0c\n\x08SATURDAY\x10\x06\"A\n\x08Schedule\x12\x35\n\x0e\x64\x61ily_schedule\x18\x01 \x03(\x0b\x32\x1d.l5kit.maps.DailyTimeInterval\"[\n\tCondition\x12\x41\n\x18\x64\x61ily_temporal_condition\x18\x01 \x01(\x0b\x32\x1d.l5kit.maps.DailyTimeIntervalH\x00\x42\x0b\n\tcondition\"\xdc\x10\n\x12RoadNetworkSegment\x12)\n\x08vertices\x18\x01 \x03(\x0b\x32\x17.l5kit.maps.GeoLocation\x12(\n\nstart_node\x18\x02 \x01(\x0b\x32\x14.l5kit.maps.GlobalId\x12&\n\x08\x65nd_node\x18\x03 \x01(\x0b\x32\x14.l5kit.maps.GlobalId\x12@\n\x10\x66orward_lane_set\x18\x04 \x01(\x0b\x32&.l5kit.maps.RoadNetworkSegment.LaneSet\x12\x41\n\x11\x62\x61\x63kward_lane_set\x18\r \x01(\x0b\x32&.l5kit.maps.RoadNetworkSegment.LaneSet\x12\x1f\n\x17num_bidirectional_lanes\x18\x0f \x01(\x05\x12#\n\x05lanes\x18\x0c \x03(\x0b\x32\x14.l5kit.maps.GlobalId\x12)\n\x04name\x18\x05 \x03(\x0b\x32\x1b.l5kit.maps.LocalizedString\x12<\n\nroad_class\x18\x06 \x01(\x0e\x32(.l5kit.maps.RoadNetworkSegment.RoadClass\x12\x12\n\nis_private\x18\x0e \x01(\x08\x12\x14\n\x0cis_toll_road\x18\x11 \x01(\x08\x12H\n\x10travel_direction\x18\x07 \x01(\x0e\x32..l5kit.maps.RoadNetworkSegment.TravelDirection\x12\x0f\n\x07z_level\x18\x08 \x01(\x11\x12%\n\x1dspeed_limit_meters_per_second\x18\t \x01(\x02\x12\x38\n0backward_direction_speed_limit_meters_per_second\x18\n \x01(\x02\x12*\n\x0crestrictions\x18\x0b \x03(\x0b\x32\x14.l5kit.maps.GlobalId\x12\x11\n\tdriveable\x18\x14 \x01(\x08\x12>\n\x08walkable\x18\x15 \x01(\x0e\x32,.l5kit.maps.RoadNetworkSegment.SideOfSegment\x12\x43\n\x10\x66orward_bikeable\x18\x17 \x01(\x0e\x32).l5kit.maps.RoadNetworkSegment.BikeAccess\x12\x44\n\x11\x62\x61\x63kward_bikeable\x18\x18 \x01(\x0e\x32).l5kit.maps.RoadNetworkSegment.BikeAccess\x1a\xed\x02\n\x07LaneSet\x12\x19\n\x11num_driving_lanes\x18\x01 \x01(\x05\x12#\n\x1bnum_left_turn_driving_lanes\x18\x02 \x01(\x05\x12$\n\x1cnum_right_turn_driving_lanes\x18\x03 \x01(\x05\x12+\n#turn_descriptions_for_driving_lanes\x18\x04 \x01(\t\x12O\n\x10\x62ike_lane_access\x18\x10 \x03(\x0e\x32\x35.l5kit.maps.RoadNetworkSegment.LaneSet.BikeLaneAccess\"~\n\x0e\x42ikeLaneAccess\x12\x17\n\x13UNKNOWN_BIKE_ACCESS\x10\x00\x12\x06\n\x02NO\x10\x01\x12\n\n\x06SHARED\x10\x02\x12\x0e\n\nDESIGNATED\x10\x03\x12\x18\n\x14\x44\x45SIGNATED_BACKWARDS\x10\x04\x12\x15\n\x11\x44\x45SIGNATED_SHARED\x10\x05\"\xbd\x03\n\tRoadClass\x12\x16\n\x12UNKNOWN_ROAD_CLASS\x10\x00\x12\x0c\n\x08MOTORWAY\x10\x01\x12\t\n\x05TRUNK\x10\x02\x12\x0b\n\x07PRIMARY\x10\x03\x12\r\n\tSECONDARY\x10\x04\x12\x0c\n\x08TERTIARY\x10\x05\x12\x0f\n\x0bRESIDENTIAL\x10\x06\x12\x10\n\x0cUNCLASSIFIED\x10\x07\x12\x0b\n\x07SERVICE\x10\x08\x12\x19\n\x15SERVICE_PARKING_AISLE\x10\t\x12\x14\n\x10SERVICE_DRIVEWAY\x10\n\x12\x11\n\rSERVICE_ALLEY\x10\x0b\x12\x1c\n\x18SERVICE_EMERGENCY_ACCESS\x10\x0c\x12\x19\n\x15SERVICE_DRIVE_THROUGH\x10\r\x12\x11\n\rMOTORWAY_LINK\x10\x0e\x12\x0e\n\nTRUNK_LINK\x10\x0f\x12\x10\n\x0cPRIMARY_LINK\x10\x10\x12\x12\n\x0eSECONDARY_LINK\x10\x11\x12\x11\n\rTERTIARY_LINK\x10\x12\x12\x19\n\x15SERVICE_LIVING_STREET\x10\x13\x12\x0e\n\nPEDESTRIAN\x10\x14\x12\x08\n\x04PATH\x10\x15\x12\t\n\x05STEPS\x10\x16\x12\x0c\n\x08\x43YCLEWAY\x10\x17\"\x7f\n\x0fTravelDirection\x12\x1c\n\x18UNKNOWN_TRAVEL_DIRECTION\x10\x00\x12\x0b\n\x07TWO_WAY\x10\x01\x12\x13\n\x0fONE_WAY_FORWARD\x10\x02\x12\x14\n\x10ONE_WAY_BACKWARD\x10\x03\x12\x16\n\x12ONE_WAY_REVERSIBLE\x10\x04\"\x8a\x01\n\rSideOfSegment\x12\x1b\n\x17UNKNOWN_SIDE_OF_SEGMENT\x10\x00\x12\x1a\n\x16\x45ITHER_SIDE_OF_SEGMENT\x10\x01\x12\x10\n\x0cSEGMENT_LEFT\x10\x02\x12\x11\n\rSEGMENT_RIGHT\x10\x03\x12\x1b\n\x17NEITHER_SIDE_OF_SEGMENT\x10\x04\"a\n\nBikeAccess\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0bNOT_ALLOWED\x10\x01\x12\x0b\n\x07\x41LLOWED\x10\x02\x12\n\n\x06SHARED\x10\x03\x12\r\n\tDEDICATED\x10\x04\x12\r\n\tPROTECTED\x10\x05J\x04\x08\x16\x10\x17\"\xbe\x01\n\x08Junction\x12#\n\x1bis_non_trivial_intersection\x18\x04 \x01(\x08\x12\x30\n\x12road_network_nodes\x18\x01 \x03(\x0b\x32\x14.l5kit.maps.GlobalId\x12#\n\x05lanes\x18\x03 \x03(\x0b\x32\x14.l5kit.maps.GlobalId\x12\x36\n\x18traffic_control_elements\x18\x02 \x03(\x0b\x32\x14.l5kit.maps.GlobalId\"\xbb\n\n\x04Lane\x12\x38\n\x1aparent_segment_or_junction\x18\x01 \x01(\x0b\x32\x14.l5kit.maps.GlobalId\x12\x39\n\x12\x61\x63\x63\x65ss_restriction\x18\x0b \x01(\x0b\x32\x1d.l5kit.maps.AccessRestriction\x12U\n\x1dorientation_in_parent_segment\x18\x0c \x01(\x0e\x32..l5kit.maps.RoadNetworkSegment.TravelDirection\x12?\n\x1cturn_type_in_parent_junction\x18\r \x01(\x0e\x32\x19.l5kit.maps.Lane.TurnType\x12\'\n\tgeo_frame\x18\x02 \x01(\x0b\x32\x14.l5kit.maps.GeoFrame\x12\x30\n\rleft_boundary\x18\x03 \x01(\x0b\x32\x19.l5kit.maps.Lane.Boundary\x12\x31\n\x0eright_boundary\x18\x04 \x01(\x0b\x32\x19.l5kit.maps.Lane.Boundary\x12)\n\x0blanes_ahead\x18\x05 \x03(\x0b\x32\x14.l5kit.maps.GlobalId\x12\x37\n\x19\x61\x64jacent_lane_change_left\x18\x06 \x01(\x0b\x32\x14.l5kit.maps.GlobalId\x12\x38\n\x1a\x61\x64jacent_lane_change_right\x18\x07 \x01(\x0b\x32\x14.l5kit.maps.GlobalId\x12.\n\x10traffic_controls\x18\x08 \x03(\x0b\x32\x14.l5kit.maps.GlobalId\x12,\n\x0eyield_to_lanes\x18\t \x03(\x0b\x32\x14.l5kit.maps.GlobalId\x12\x1c\n\x14\x63\x61n_have_parked_cars\x18\n \x01(\x08\x12#\n\x05tolls\x18\x0e \x03(\x0b\x32\x14.l5kit.maps.GlobalId\x1a\xf0\x03\n\x08\x42oundary\x12\x1a\n\x12vertex_deltas_x_cm\x18\x01 \x03(\x11\x12\x1a\n\x12vertex_deltas_y_cm\x18\x02 \x03(\x11\x12\x1a\n\x12vertex_deltas_z_cm\x18\x03 \x03(\x11\x12;\n\x0c\x64ivider_type\x18\x04 \x03(\x0e\x32%.l5kit.maps.Lane.Boundary.DividerType\x12\x1c\n\x14type_change_point_cm\x18\x05 \x03(\x05\"\xb4\x02\n\x0b\x44ividerType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x17\n\x13SINGLE_YELLOW_SOLID\x10\x02\x12\x16\n\x12SINGLE_WHITE_SOLID\x10\x03\x12\x18\n\x14SINGLE_YELLOW_DASHED\x10\x04\x12\x17\n\x13SINGLE_WHITE_DASHED\x10\x05\x12\x17\n\x13\x44OUBLE_YELLOW_SOLID\x10\x06\x12\x16\n\x12\x44OUBLE_WHITE_SOLID\x10\x07\x12\'\n#DOUBLE_YELLOW_SOLID_FAR_DASHED_NEAR\x10\x08\x12\'\n#DOUBLE_YELLOW_DASHED_FAR_SOLID_NEAR\x10\t\x12\x0c\n\x08\x43URB_RED\x10\n\x12\x0f\n\x0b\x43URB_YELLOW\x10\x0b\x12\x08\n\x04\x43URB\x10\x0c\"f\n\x08TurnType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07THROUGH\x10\x01\x12\x08\n\x04LEFT\x10\x02\x12\x0e\n\nSHARP_LEFT\x10\x03\x12\t\n\x05RIGHT\x10\x04\x12\x0f\n\x0bSHARP_RIGHT\x10\x05\x12\n\n\x06U_TURN\x10\x06\"\xf9)\n\x15TrafficControlElement\x12+\n\tstop_sign\x18\x07 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12,\n\nyield_sign\x18\x08 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12G\n\tstop_line\x18/ \x01(\x0b\x32\x32.l5kit.maps.TrafficControlElement.AuxiliaryElementH\x00\x12G\n\rtraffic_light\x18\x1d \x01(\x0b\x32..l5kit.maps.TrafficControlElement.TrafficLightH\x00\x12Y\n\x16signal_flashing_yellow\x18\t \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12V\n\x13signal_flashing_red\x18\n \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12R\n\x0fsignal_red_face\x18\x0b \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12U\n\x12signal_yellow_face\x18\x0c \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12T\n\x11signal_green_face\x18\r \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12]\n\x1asignal_left_arrow_red_face\x18\x1e \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12`\n\x1dsignal_left_arrow_yellow_face\x18$ \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12_\n\x1csignal_left_arrow_green_face\x18\x1f \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12^\n\x1bsignal_right_arrow_red_face\x18  \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12\x61\n\x1esignal_right_arrow_yellow_face\x18% \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12`\n\x1dsignal_right_arrow_green_face\x18! \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12\x63\n signal_upper_left_arrow_red_face\x18& \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12\x66\n#signal_upper_left_arrow_yellow_face\x18\' \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12\x65\n\"signal_upper_left_arrow_green_face\x18( \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12\x64\n!signal_upper_right_arrow_red_face\x18) \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12g\n$signal_upper_right_arrow_yellow_face\x18* \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12\x66\n#signal_upper_right_arrow_green_face\x18+ \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12T\n\x11signal_red_u_turn\x18, \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12W\n\x14signal_yellow_u_turn\x18- \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12V\n\x13signal_green_u_turn\x18. \x01(\x0b\x32\x37.l5kit.maps.TrafficControlElement.TrafficLightFaceStateH\x00\x12,\n\nspeed_bump\x18\x0f \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12,\n\nspeed_hump\x18\" \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12U\n\x14pedestrian_crosswalk\x18\x10 \x01(\x0b\x32\x35.l5kit.maps.TrafficControlElement.PedestrianCrosswalkH\x00\x12\x31\n\x0fkeep_clear_zone\x18\x11 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12:\n\x18pedestrian_crossing_sign\x18\x12 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x33\n\x11signal_ahead_sign\x18\x13 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x33\n\x11no_left_turn_sign\x18\x14 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x34\n\x12no_right_turn_sign\x18\x15 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12?\n\x1dleft_turn_yield_on_green_sign\x18\x16 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x31\n\x0fno_parking_sign\x18\x17 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12.\n\x0cone_way_sign\x18\x18 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x32\n\x10school_zone_sign\x18\x19 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12.\n\x0cparking_zone\x18# \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x31\n\x0fspeed_bump_sign\x18\x1b \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x33\n\x11\x63onstruction_zone\x18\x31 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12@\n\x1estop_here_for_pedestrians_sign\x18\x32 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12Q\n/state_law_stop_for_pedestrian_in_crosswalk_sign\x18\x33 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x41\n\x1fyield_here_for_pedestrians_sign\x18\x34 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12L\n*turning_vehicles_yield_to_pedestrians_sign\x18\x35 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x45\n#state_law_yield_for_pedestrian_sign\x18\x36 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x43\n!railroad_crossing_regulatory_sign\x18\x37 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12@\n\x1erailroad_crossing_warning_sign\x18\x38 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12>\n\x1crailroad_crossing_other_sign\x18\x39 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12=\n\x1broundabout_circulation_sign\x18: \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12=\n\x1broundabout_directional_sign\x18; \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x37\n\x15roundabout_other_sign\x18< \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12:\n\x18no_left_turn_on_red_sign\x18= \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12;\n\x19no_right_turn_on_red_sign\x18> \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x35\n\x13no_turn_on_red_sign\x18? \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x33\n\x11\x64o_not_enter_sign\x18@ \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x30\n\x0eno_u_turn_sign\x18\x41 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x39\n\x17no_left_and_u_turn_sign\x18\x42 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12:\n\x18no_straight_through_sign\x18\x43 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x35\n\x13left_turn_only_sign\x18\x44 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x36\n\x14right_turn_only_sign\x18\x45 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x32\n\x10u_turn_only_sign\x18\x46 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12<\n\x1astraight_through_only_sign\x18G \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12=\n\x1bother_turn_restriction_sign\x18H \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x38\n\x16\x63onstruction_zone_sign\x18I \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\'\n\tgeo_frame\x18\x02 \x01(\x0b\x32\x14.l5kit.maps.GeoFrame\x12\x1a\n\x12points_x_deltas_cm\x18\x03 \x03(\x11\x12\x1a\n\x12points_y_deltas_cm\x18\x04 \x03(\x11\x12\x1a\n\x12points_z_deltas_cm\x18\x05 \x03(\x11\x12\x45\n\rgeometry_type\x18\x30 \x01(\x0e\x32..l5kit.maps.TrafficControlElement.GeometryType\x12\x32\n\x10\x63ontrolled_paths\x18\x06 \x03(\x0b\x32\x18.l5kit.maps.LaneSequence\x1an\n\x13PedestrianCrosswalk\x12,\n\x0etraffic_lights\x18\x01 \x03(\x0b\x32\x14.l5kit.maps.GlobalId\x12)\n\x0byield_lines\x18\x02 \x03(\x0b\x32\x14.l5kit.maps.GlobalId\x1aR\n\x10\x41uxiliaryElement\x12>\n primary_traffic_control_elements\x18\x01 \x03(\x0b\x32\x14.l5kit.maps.GlobalId\x1a\xa6\x02\n\x15TrafficLightFaceState\x12]\n\x13yield_rules_when_on\x18\x01 \x03(\x0b\x32@.l5kit.maps.TrafficControlElement.TrafficLightFaceState.YieldSet\x12\x1c\n\x14no_right_turn_on_red\x18\x02 \x01(\x08\x1a\x8f\x01\n\x08YieldSet\x12\"\n\x04lane\x18\x01 \x01(\x0b\x32\x14.l5kit.maps.GlobalId\x12,\n\x0eyield_to_lanes\x18\x02 \x03(\x0b\x32\x14.l5kit.maps.GlobalId\x12\x31\n\x13yield_to_crosswalks\x18\x03 \x03(\x0b\x32\x14.l5kit.maps.GlobalId\x1a\x39\n\x0cTrafficLight\x12)\n\x0b\x66\x61\x63\x65_states\x18\x03 \x03(\x0b\x32\x14.l5kit.maps.GlobalId\"S\n\x0cGeometryType\x12\n\n\x06UKNOWN\x10\x00\x12\t\n\x05POINT\x10\x01\x12\x0f\n\x0bMULTI_POINT\x10\x02\x12\x0e\n\nLINESTRING\x10\x03\x12\x0b\n\x07POLYGON\x10\x04\x42\x06\n\x04TypeJ\x04\x08\x0e\x10\x0f\"\x88\x03\n\x0fSegmentSequence\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .l5kit.maps.SegmentSequence.Type\x12\x44\n\x08segments\x18\x02 \x03(\x0b\x32\x32.l5kit.maps.SegmentSequence.SegmentWithOrientation\x1a\xcb\x01\n\x16SegmentWithOrientation\x12%\n\x07segment\x18\x01 \x01(\x0b\x32\x14.l5kit.maps.GlobalId\x12S\n\x0borientation\x18\x02 \x01(\x0e\x32>.l5kit.maps.SegmentSequence.SegmentWithOrientation.Orientation\"5\n\x0bOrientation\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x46ORWARD\x10\x01\x12\x0c\n\x08\x42\x41\x43KWARD\x10\x02\"1\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tFORBIDDEN\x10\x01\x12\r\n\tMANDATORY\x10\x02\"3\n\x0cLaneSequence\x12#\n\x05lanes\x18\x01 \x03(\x0b\x32\x14.l5kit.maps.GlobalId\"A\n\rLaneSequences\x12\x30\n\x0elane_sequences\x18\x01 \x03(\x0b\x32\x18.l5kit.maps.LaneSequence\"^\n\x07Polygon\x12/\n\x0eshell_vertices\x18\x01 \x03(\x0b\x32\x17.l5kit.maps.GeoLocation\x12\"\n\x05holes\x18\x02 \x03(\x0b\x32\x13.l5kit.maps.Polygon\"5\n\x0cMultiPolygon\x12%\n\x08polygons\x18\x01 \x03(\x0b\x32\x13.l5kit.maps.Polygon\"\xe7\x05\n\x0e\x41nnotatedShape\x12)\n\x04name\x18\x01 \x03(\x0b\x32\x1b.l5kit.maps.LocalizedString\x12.\n\x0cmultipolygon\x18\x02 \x01(\x0b\x32\x18.l5kit.maps.MultiPolygon\x12\x37\n\x08\x62uilding\x18\x03 \x01(\x0b\x32#.l5kit.maps.AnnotatedShape.BuildingH\x00\x12\x33\n\x06region\x18\x04 \x01(\x0b\x32!.l5kit.maps.AnnotatedShape.RegionH\x00\x12\'\n\x05venue\x18\x05 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x39\n\x17\x61\x64ministrative_boundary\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12&\n\x04park\x18\x07 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x38\n\x16\x64rivable_surface_prior\x18\x08 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x1a\xa3\x02\n\x08\x42uilding\x12\x36\n\x04type\x18\x01 \x01(\x0e\x32(.l5kit.maps.AnnotatedShape.Building.Type\x12\x15\n\rheight_meters\x18\x02 \x01(\x05\x12\x1b\n\x13\x61\x62ove_ground_floors\x18\x03 \x01(\x05\"\xaa\x01\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nCOMMERCIAL\x10\x01\x12\x0f\n\x0bRESIDENTIAL\x10\x02\x12\x12\n\x0eTRANSPORTATION\x10\x03\x12\x0c\n\x08HOSPITAL\x10\x04\x12\t\n\x05\x45VENT\x10\x05\x12\x15\n\x11PARKING_STRUCTURE\x10\x06\x12\r\n\tRELIGIOUS\x10\x07\x12\x0f\n\x0b\x45\x44UCATIONAL\x10\x08\x12\x10\n\x0cGOVERNMENTAL\x10\t\x1a\x18\n\x06Region\x12\x0e\n\x06source\x18\x01 \x01(\tB\x06\n\x04Type\"e\n\tLatLngBox\x12+\n\nsouth_west\x18\x01 \x01(\x0b\x32\x17.l5kit.maps.GeoLocation\x12+\n\nnorth_east\x18\x02 \x01(\x0b\x32\x17.l5kit.maps.GeoLocation\"\xc7\x05\n\nMapElement\x12 \n\x02id\x18\x01 \x01(\x0b\x32\x14.l5kit.maps.GlobalId\x12/\n\x07\x65lement\x18\x02 \x01(\x0b\x32\x1e.l5kit.maps.MapElement.Element\x12+\n\x0c\x62ounding_box\x18\x03 \x01(\x0b\x32\x15.l5kit.maps.LatLngBox\x12J\n\x15\x61ssociated_conditions\x18\x05 \x03(\x0b\x32+.l5kit.maps.MapElement.AssociatedConditions\x1a\xf6\x02\n\x07\x45lement\x12\x31\n\x07segment\x18\x01 \x01(\x0b\x32\x1e.l5kit.maps.RoadNetworkSegmentH\x00\x12+\n\x04node\x18\x02 \x01(\x0b\x32\x1b.l5kit.maps.RoadNetworkNodeH\x00\x12 \n\x04lane\x18\x03 \x01(\x0b\x32\x10.l5kit.maps.LaneH\x00\x12\x44\n\x17traffic_control_element\x18\x04 \x01(\x0b\x32!.l5kit.maps.TrafficControlElementH\x00\x12(\n\x08junction\x18\x05 \x01(\x0b\x32\x14.l5kit.maps.JunctionH\x00\x12\x37\n\x10segment_sequence\x18\x06 \x01(\x0b\x32\x1b.l5kit.maps.SegmentSequenceH\x00\x12\x35\n\x0f\x61nnotated_shape\x18\x08 \x01(\x0b\x32\x1a.l5kit.maps.AnnotatedShapeH\x00\x42\t\n\x07\x65lement\x1at\n\x14\x41ssociatedConditions\x12)\n\nconditions\x18\x01 \x03(\x0b\x32\x15.l5kit.maps.Condition\x12\x31\n\toverrides\x18\x02 \x01(\x0b\x32\x1e.l5kit.maps.MapElement.Element\"E\n\x0bMapFragment\x12\x0c\n\x04name\x18\x01 \x01(\t\x12(\n\x08\x65lements\x18\x02 \x03(\x0b\x32\x16.l5kit.maps.MapElementB\x06Z\x04mapsb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])



_ACCESSRESTRICTION_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='l5kit.maps.AccessRestriction.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_RESTRICTION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONLY_HOV', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONLY_BUS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONLY_BIKE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONLY_TURN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=575,
  serialized_end=672,
)
_sym_db.RegisterEnumDescriptor(_ACCESSRESTRICTION_TYPE)

_DAILYTIMEINTERVAL_DAYOFTHEWEEK = _descriptor.EnumDescriptor(
  name='DayOfTheWeek',
  full_name='l5kit.maps.DailyTimeInterval.DayOfTheWeek',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUNDAY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONDAY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TUESDAY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEDNESDAY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THURSDAY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRIDAY', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SATURDAY', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=870,
  serialized_end=976,
)
_sym_db.RegisterEnumDescriptor(_DAILYTIMEINTERVAL_DAYOFTHEWEEK)

_ROADNETWORKSEGMENT_LANESET_BIKELANEACCESS = _descriptor.EnumDescriptor(
  name='BikeLaneAccess',
  full_name='l5kit.maps.RoadNetworkSegment.LaneSet.BikeLaneAccess',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_BIKE_ACCESS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHARED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DESIGNATED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DESIGNATED_BACKWARDS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DESIGNATED_SHARED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2330,
  serialized_end=2456,
)
_sym_db.RegisterEnumDescriptor(_ROADNETWORKSEGMENT_LANESET_BIKELANEACCESS)

_ROADNETWORKSEGMENT_ROADCLASS = _descriptor.EnumDescriptor(
  name='RoadClass',
  full_name='l5kit.maps.RoadNetworkSegment.RoadClass',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ROAD_CLASS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOTORWAY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRUNK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMARY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECONDARY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TERTIARY', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESIDENTIAL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNCLASSIFIED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVICE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_PARKING_AISLE', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_DRIVEWAY', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ALLEY', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_EMERGENCY_ACCESS', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_DRIVE_THROUGH', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOTORWAY_LINK', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRUNK_LINK', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMARY_LINK', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECONDARY_LINK', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TERTIARY_LINK', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_LIVING_STREET', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PATH', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STEPS', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CYCLEWAY', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2459,
  serialized_end=2904,
)
_sym_db.RegisterEnumDescriptor(_ROADNETWORKSEGMENT_ROADCLASS)

_ROADNETWORKSEGMENT_TRAVELDIRECTION = _descriptor.EnumDescriptor(
  name='TravelDirection',
  full_name='l5kit.maps.RoadNetworkSegment.TravelDirection',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_TRAVEL_DIRECTION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TWO_WAY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONE_WAY_FORWARD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONE_WAY_BACKWARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONE_WAY_REVERSIBLE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2906,
  serialized_end=3033,
)
_sym_db.RegisterEnumDescriptor(_ROADNETWORKSEGMENT_TRAVELDIRECTION)

_ROADNETWORKSEGMENT_SIDEOFSEGMENT = _descriptor.EnumDescriptor(
  name='SideOfSegment',
  full_name='l5kit.maps.RoadNetworkSegment.SideOfSegment',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_SIDE_OF_SEGMENT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EITHER_SIDE_OF_SEGMENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEGMENT_LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEGMENT_RIGHT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEITHER_SIDE_OF_SEGMENT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3036,
  serialized_end=3174,
)
_sym_db.RegisterEnumDescriptor(_ROADNETWORKSEGMENT_SIDEOFSEGMENT)

_ROADNETWORKSEGMENT_BIKEACCESS = _descriptor.EnumDescriptor(
  name='BikeAccess',
  full_name='l5kit.maps.RoadNetworkSegment.BikeAccess',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_ALLOWED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALLOWED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHARED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEDICATED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROTECTED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3176,
  serialized_end=3273,
)
_sym_db.RegisterEnumDescriptor(_ROADNETWORKSEGMENT_BIKEACCESS)

_LANE_BOUNDARY_DIVIDERTYPE = _descriptor.EnumDescriptor(
  name='DividerType',
  full_name='l5kit.maps.Lane.Boundary.DividerType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SINGLE_YELLOW_SOLID', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SINGLE_WHITE_SOLID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SINGLE_YELLOW_DASHED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SINGLE_WHITE_DASHED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE_YELLOW_SOLID', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE_WHITE_SOLID', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE_YELLOW_SOLID_FAR_DASHED_NEAR', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE_YELLOW_DASHED_FAR_SOLID_NEAR', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CURB_RED', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CURB_YELLOW', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CURB', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4402,
  serialized_end=4710,
)
_sym_db.RegisterEnumDescriptor(_LANE_BOUNDARY_DIVIDERTYPE)

_LANE_TURNTYPE = _descriptor.EnumDescriptor(
  name='TurnType',
  full_name='l5kit.maps.Lane.TurnType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THROUGH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHARP_LEFT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHARP_RIGHT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U_TURN', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4712,
  serialized_end=4814,
)
_sym_db.RegisterEnumDescriptor(_LANE_TURNTYPE)

_TRAFFICCONTROLELEMENT_GEOMETRYTYPE = _descriptor.EnumDescriptor(
  name='GeometryType',
  full_name='l5kit.maps.TrafficControlElement.GeometryType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POINT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MULTI_POINT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINESTRING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POLYGON', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10089,
  serialized_end=10172,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICCONTROLELEMENT_GEOMETRYTYPE)

_SEGMENTSEQUENCE_SEGMENTWITHORIENTATION_ORIENTATION = _descriptor.EnumDescriptor(
  name='Orientation',
  full_name='l5kit.maps.SegmentSequence.SegmentWithOrientation.Orientation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORWARD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BACKWARD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10477,
  serialized_end=10530,
)
_sym_db.RegisterEnumDescriptor(_SEGMENTSEQUENCE_SEGMENTWITHORIENTATION_ORIENTATION)

_SEGMENTSEQUENCE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='l5kit.maps.SegmentSequence.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORBIDDEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANDATORY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10532,
  serialized_end=10581,
)
_sym_db.RegisterEnumDescriptor(_SEGMENTSEQUENCE_TYPE)

_ANNOTATEDSHAPE_BUILDING_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='l5kit.maps.AnnotatedShape.Building.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMERCIAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESIDENTIAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSPORTATION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOSPITAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_STRUCTURE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELIGIOUS', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EDUCATIONAL', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GOVERNMENTAL', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11394,
  serialized_end=11564,
)
_sym_db.RegisterEnumDescriptor(_ANNOTATEDSHAPE_BUILDING_TYPE)


_GLOBALID = _descriptor.Descriptor(
  name='GlobalId',
  full_name='l5kit.maps.GlobalId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='l5kit.maps.GlobalId.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=119,
)


_GEOLOCATION = _descriptor.Descriptor(
  name='GeoLocation',
  full_name='l5kit.maps.GeoLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lat_e7', full_name='l5kit.maps.GeoLocation.lat_e7', index=0,
      number=1, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lng_e7', full_name='l5kit.maps.GeoLocation.lng_e7', index=1,
      number=2, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='altitude_cm', full_name='l5kit.maps.GeoLocation.altitude_cm', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Altitude', full_name='l5kit.maps.GeoLocation.Altitude',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=121,
  serialized_end=201,
)


_GEOFRAME = _descriptor.Descriptor(
  name='GeoFrame',
  full_name='l5kit.maps.GeoFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='l5kit.maps.GeoFrame.origin', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bearing_degrees', full_name='l5kit.maps.GeoFrame.bearing_degrees', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=279,
)


_LOCALIZEDSTRING = _descriptor.Descriptor(
  name='LocalizedString',
  full_name='l5kit.maps.LocalizedString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language_code', full_name='l5kit.maps.LocalizedString.language_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='l5kit.maps.LocalizedString.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=336,
)


_ROADNETWORKNODE = _descriptor.Descriptor(
  name='RoadNetworkNode',
  full_name='l5kit.maps.RoadNetworkNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='l5kit.maps.RoadNetworkNode.location', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road_segments', full_name='l5kit.maps.RoadNetworkNode.road_segments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z_level', full_name='l5kit.maps.RoadNetworkNode.z_level', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction', full_name='l5kit.maps.RoadNetworkNode.junction', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=501,
)


_ACCESSRESTRICTION = _descriptor.Descriptor(
  name='AccessRestriction',
  full_name='l5kit.maps.AccessRestriction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='l5kit.maps.AccessRestriction.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ACCESSRESTRICTION_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=672,
)


_DAILYTIMEINTERVAL = _descriptor.Descriptor(
  name='DailyTimeInterval',
  full_name='l5kit.maps.DailyTimeInterval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='day_of_the_week', full_name='l5kit.maps.DailyTimeInterval.day_of_the_week', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_local_time_seconds', full_name='l5kit.maps.DailyTimeInterval.start_local_time_seconds', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_local_time_seconds', full_name='l5kit.maps.DailyTimeInterval.end_local_time_seconds', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timezone_database_region_name', full_name='l5kit.maps.DailyTimeInterval.timezone_database_region_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DAILYTIMEINTERVAL_DAYOFTHEWEEK,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=675,
  serialized_end=976,
)


_SCHEDULE = _descriptor.Descriptor(
  name='Schedule',
  full_name='l5kit.maps.Schedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='daily_schedule', full_name='l5kit.maps.Schedule.daily_schedule', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=978,
  serialized_end=1043,
)


_CONDITION = _descriptor.Descriptor(
  name='Condition',
  full_name='l5kit.maps.Condition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='daily_temporal_condition', full_name='l5kit.maps.Condition.daily_temporal_condition', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='condition', full_name='l5kit.maps.Condition.condition',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1045,
  serialized_end=1136,
)


_ROADNETWORKSEGMENT_LANESET = _descriptor.Descriptor(
  name='LaneSet',
  full_name='l5kit.maps.RoadNetworkSegment.LaneSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_driving_lanes', full_name='l5kit.maps.RoadNetworkSegment.LaneSet.num_driving_lanes', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_left_turn_driving_lanes', full_name='l5kit.maps.RoadNetworkSegment.LaneSet.num_left_turn_driving_lanes', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_right_turn_driving_lanes', full_name='l5kit.maps.RoadNetworkSegment.LaneSet.num_right_turn_driving_lanes', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turn_descriptions_for_driving_lanes', full_name='l5kit.maps.RoadNetworkSegment.LaneSet.turn_descriptions_for_driving_lanes', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bike_lane_access', full_name='l5kit.maps.RoadNetworkSegment.LaneSet.bike_lane_access', index=4,
      number=16, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ROADNETWORKSEGMENT_LANESET_BIKELANEACCESS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2091,
  serialized_end=2456,
)

_ROADNETWORKSEGMENT = _descriptor.Descriptor(
  name='RoadNetworkSegment',
  full_name='l5kit.maps.RoadNetworkSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vertices', full_name='l5kit.maps.RoadNetworkSegment.vertices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_node', full_name='l5kit.maps.RoadNetworkSegment.start_node', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_node', full_name='l5kit.maps.RoadNetworkSegment.end_node', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward_lane_set', full_name='l5kit.maps.RoadNetworkSegment.forward_lane_set', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backward_lane_set', full_name='l5kit.maps.RoadNetworkSegment.backward_lane_set', index=4,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_bidirectional_lanes', full_name='l5kit.maps.RoadNetworkSegment.num_bidirectional_lanes', index=5,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lanes', full_name='l5kit.maps.RoadNetworkSegment.lanes', index=6,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='l5kit.maps.RoadNetworkSegment.name', index=7,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road_class', full_name='l5kit.maps.RoadNetworkSegment.road_class', index=8,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_private', full_name='l5kit.maps.RoadNetworkSegment.is_private', index=9,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_toll_road', full_name='l5kit.maps.RoadNetworkSegment.is_toll_road', index=10,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='travel_direction', full_name='l5kit.maps.RoadNetworkSegment.travel_direction', index=11,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z_level', full_name='l5kit.maps.RoadNetworkSegment.z_level', index=12,
      number=8, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_limit_meters_per_second', full_name='l5kit.maps.RoadNetworkSegment.speed_limit_meters_per_second', index=13,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backward_direction_speed_limit_meters_per_second', full_name='l5kit.maps.RoadNetworkSegment.backward_direction_speed_limit_meters_per_second', index=14,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='restrictions', full_name='l5kit.maps.RoadNetworkSegment.restrictions', index=15,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driveable', full_name='l5kit.maps.RoadNetworkSegment.driveable', index=16,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='walkable', full_name='l5kit.maps.RoadNetworkSegment.walkable', index=17,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward_bikeable', full_name='l5kit.maps.RoadNetworkSegment.forward_bikeable', index=18,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backward_bikeable', full_name='l5kit.maps.RoadNetworkSegment.backward_bikeable', index=19,
      number=24, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ROADNETWORKSEGMENT_LANESET, ],
  enum_types=[
    _ROADNETWORKSEGMENT_ROADCLASS,
    _ROADNETWORKSEGMENT_TRAVELDIRECTION,
    _ROADNETWORKSEGMENT_SIDEOFSEGMENT,
    _ROADNETWORKSEGMENT_BIKEACCESS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1139,
  serialized_end=3279,
)


_JUNCTION = _descriptor.Descriptor(
  name='Junction',
  full_name='l5kit.maps.Junction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_non_trivial_intersection', full_name='l5kit.maps.Junction.is_non_trivial_intersection', index=0,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road_network_nodes', full_name='l5kit.maps.Junction.road_network_nodes', index=1,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lanes', full_name='l5kit.maps.Junction.lanes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_control_elements', full_name='l5kit.maps.Junction.traffic_control_elements', index=3,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3282,
  serialized_end=3472,
)


_LANE_BOUNDARY = _descriptor.Descriptor(
  name='Boundary',
  full_name='l5kit.maps.Lane.Boundary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vertex_deltas_x_cm', full_name='l5kit.maps.Lane.Boundary.vertex_deltas_x_cm', index=0,
      number=1, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vertex_deltas_y_cm', full_name='l5kit.maps.Lane.Boundary.vertex_deltas_y_cm', index=1,
      number=2, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vertex_deltas_z_cm', full_name='l5kit.maps.Lane.Boundary.vertex_deltas_z_cm', index=2,
      number=3, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='divider_type', full_name='l5kit.maps.Lane.Boundary.divider_type', index=3,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_change_point_cm', full_name='l5kit.maps.Lane.Boundary.type_change_point_cm', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LANE_BOUNDARY_DIVIDERTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4214,
  serialized_end=4710,
)

_LANE = _descriptor.Descriptor(
  name='Lane',
  full_name='l5kit.maps.Lane',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_segment_or_junction', full_name='l5kit.maps.Lane.parent_segment_or_junction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_restriction', full_name='l5kit.maps.Lane.access_restriction', index=1,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orientation_in_parent_segment', full_name='l5kit.maps.Lane.orientation_in_parent_segment', index=2,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turn_type_in_parent_junction', full_name='l5kit.maps.Lane.turn_type_in_parent_junction', index=3,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_frame', full_name='l5kit.maps.Lane.geo_frame', index=4,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_boundary', full_name='l5kit.maps.Lane.left_boundary', index=5,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_boundary', full_name='l5kit.maps.Lane.right_boundary', index=6,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lanes_ahead', full_name='l5kit.maps.Lane.lanes_ahead', index=7,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjacent_lane_change_left', full_name='l5kit.maps.Lane.adjacent_lane_change_left', index=8,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjacent_lane_change_right', full_name='l5kit.maps.Lane.adjacent_lane_change_right', index=9,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_controls', full_name='l5kit.maps.Lane.traffic_controls', index=10,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yield_to_lanes', full_name='l5kit.maps.Lane.yield_to_lanes', index=11,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_have_parked_cars', full_name='l5kit.maps.Lane.can_have_parked_cars', index=12,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tolls', full_name='l5kit.maps.Lane.tolls', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LANE_BOUNDARY, ],
  enum_types=[
    _LANE_TURNTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3475,
  serialized_end=4814,
)


_TRAFFICCONTROLELEMENT_PEDESTRIANCROSSWALK = _descriptor.Descriptor(
  name='PedestrianCrosswalk',
  full_name='l5kit.maps.TrafficControlElement.PedestrianCrosswalk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='traffic_lights', full_name='l5kit.maps.TrafficControlElement.PedestrianCrosswalk.traffic_lights', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yield_lines', full_name='l5kit.maps.TrafficControlElement.PedestrianCrosswalk.yield_lines', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9537,
  serialized_end=9647,
)

_TRAFFICCONTROLELEMENT_AUXILIARYELEMENT = _descriptor.Descriptor(
  name='AuxiliaryElement',
  full_name='l5kit.maps.TrafficControlElement.AuxiliaryElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='primary_traffic_control_elements', full_name='l5kit.maps.TrafficControlElement.AuxiliaryElement.primary_traffic_control_elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9649,
  serialized_end=9731,
)

_TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE_YIELDSET = _descriptor.Descriptor(
  name='YieldSet',
  full_name='l5kit.maps.TrafficControlElement.TrafficLightFaceState.YieldSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane', full_name='l5kit.maps.TrafficControlElement.TrafficLightFaceState.YieldSet.lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yield_to_lanes', full_name='l5kit.maps.TrafficControlElement.TrafficLightFaceState.YieldSet.yield_to_lanes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yield_to_crosswalks', full_name='l5kit.maps.TrafficControlElement.TrafficLightFaceState.YieldSet.yield_to_crosswalks', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9885,
  serialized_end=10028,
)

_TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE = _descriptor.Descriptor(
  name='TrafficLightFaceState',
  full_name='l5kit.maps.TrafficControlElement.TrafficLightFaceState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='yield_rules_when_on', full_name='l5kit.maps.TrafficControlElement.TrafficLightFaceState.yield_rules_when_on', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_right_turn_on_red', full_name='l5kit.maps.TrafficControlElement.TrafficLightFaceState.no_right_turn_on_red', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE_YIELDSET, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9734,
  serialized_end=10028,
)

_TRAFFICCONTROLELEMENT_TRAFFICLIGHT = _descriptor.Descriptor(
  name='TrafficLight',
  full_name='l5kit.maps.TrafficControlElement.TrafficLight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='face_states', full_name='l5kit.maps.TrafficControlElement.TrafficLight.face_states', index=0,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10030,
  serialized_end=10087,
)

_TRAFFICCONTROLELEMENT = _descriptor.Descriptor(
  name='TrafficControlElement',
  full_name='l5kit.maps.TrafficControlElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stop_sign', full_name='l5kit.maps.TrafficControlElement.stop_sign', index=0,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yield_sign', full_name='l5kit.maps.TrafficControlElement.yield_sign', index=1,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_line', full_name='l5kit.maps.TrafficControlElement.stop_line', index=2,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_light', full_name='l5kit.maps.TrafficControlElement.traffic_light', index=3,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_flashing_yellow', full_name='l5kit.maps.TrafficControlElement.signal_flashing_yellow', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_flashing_red', full_name='l5kit.maps.TrafficControlElement.signal_flashing_red', index=5,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_red_face', full_name='l5kit.maps.TrafficControlElement.signal_red_face', index=6,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_yellow_face', full_name='l5kit.maps.TrafficControlElement.signal_yellow_face', index=7,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_green_face', full_name='l5kit.maps.TrafficControlElement.signal_green_face', index=8,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_left_arrow_red_face', full_name='l5kit.maps.TrafficControlElement.signal_left_arrow_red_face', index=9,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_left_arrow_yellow_face', full_name='l5kit.maps.TrafficControlElement.signal_left_arrow_yellow_face', index=10,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_left_arrow_green_face', full_name='l5kit.maps.TrafficControlElement.signal_left_arrow_green_face', index=11,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_right_arrow_red_face', full_name='l5kit.maps.TrafficControlElement.signal_right_arrow_red_face', index=12,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_right_arrow_yellow_face', full_name='l5kit.maps.TrafficControlElement.signal_right_arrow_yellow_face', index=13,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_right_arrow_green_face', full_name='l5kit.maps.TrafficControlElement.signal_right_arrow_green_face', index=14,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_upper_left_arrow_red_face', full_name='l5kit.maps.TrafficControlElement.signal_upper_left_arrow_red_face', index=15,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_upper_left_arrow_yellow_face', full_name='l5kit.maps.TrafficControlElement.signal_upper_left_arrow_yellow_face', index=16,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_upper_left_arrow_green_face', full_name='l5kit.maps.TrafficControlElement.signal_upper_left_arrow_green_face', index=17,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_upper_right_arrow_red_face', full_name='l5kit.maps.TrafficControlElement.signal_upper_right_arrow_red_face', index=18,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_upper_right_arrow_yellow_face', full_name='l5kit.maps.TrafficControlElement.signal_upper_right_arrow_yellow_face', index=19,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_upper_right_arrow_green_face', full_name='l5kit.maps.TrafficControlElement.signal_upper_right_arrow_green_face', index=20,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_red_u_turn', full_name='l5kit.maps.TrafficControlElement.signal_red_u_turn', index=21,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_yellow_u_turn', full_name='l5kit.maps.TrafficControlElement.signal_yellow_u_turn', index=22,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_green_u_turn', full_name='l5kit.maps.TrafficControlElement.signal_green_u_turn', index=23,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_bump', full_name='l5kit.maps.TrafficControlElement.speed_bump', index=24,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_hump', full_name='l5kit.maps.TrafficControlElement.speed_hump', index=25,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pedestrian_crosswalk', full_name='l5kit.maps.TrafficControlElement.pedestrian_crosswalk', index=26,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keep_clear_zone', full_name='l5kit.maps.TrafficControlElement.keep_clear_zone', index=27,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pedestrian_crossing_sign', full_name='l5kit.maps.TrafficControlElement.pedestrian_crossing_sign', index=28,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_ahead_sign', full_name='l5kit.maps.TrafficControlElement.signal_ahead_sign', index=29,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_left_turn_sign', full_name='l5kit.maps.TrafficControlElement.no_left_turn_sign', index=30,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_right_turn_sign', full_name='l5kit.maps.TrafficControlElement.no_right_turn_sign', index=31,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_turn_yield_on_green_sign', full_name='l5kit.maps.TrafficControlElement.left_turn_yield_on_green_sign', index=32,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_parking_sign', full_name='l5kit.maps.TrafficControlElement.no_parking_sign', index=33,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='one_way_sign', full_name='l5kit.maps.TrafficControlElement.one_way_sign', index=34,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='school_zone_sign', full_name='l5kit.maps.TrafficControlElement.school_zone_sign', index=35,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_zone', full_name='l5kit.maps.TrafficControlElement.parking_zone', index=36,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_bump_sign', full_name='l5kit.maps.TrafficControlElement.speed_bump_sign', index=37,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='construction_zone', full_name='l5kit.maps.TrafficControlElement.construction_zone', index=38,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_here_for_pedestrians_sign', full_name='l5kit.maps.TrafficControlElement.stop_here_for_pedestrians_sign', index=39,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_law_stop_for_pedestrian_in_crosswalk_sign', full_name='l5kit.maps.TrafficControlElement.state_law_stop_for_pedestrian_in_crosswalk_sign', index=40,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yield_here_for_pedestrians_sign', full_name='l5kit.maps.TrafficControlElement.yield_here_for_pedestrians_sign', index=41,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turning_vehicles_yield_to_pedestrians_sign', full_name='l5kit.maps.TrafficControlElement.turning_vehicles_yield_to_pedestrians_sign', index=42,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_law_yield_for_pedestrian_sign', full_name='l5kit.maps.TrafficControlElement.state_law_yield_for_pedestrian_sign', index=43,
      number=54, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='railroad_crossing_regulatory_sign', full_name='l5kit.maps.TrafficControlElement.railroad_crossing_regulatory_sign', index=44,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='railroad_crossing_warning_sign', full_name='l5kit.maps.TrafficControlElement.railroad_crossing_warning_sign', index=45,
      number=56, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='railroad_crossing_other_sign', full_name='l5kit.maps.TrafficControlElement.railroad_crossing_other_sign', index=46,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roundabout_circulation_sign', full_name='l5kit.maps.TrafficControlElement.roundabout_circulation_sign', index=47,
      number=58, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roundabout_directional_sign', full_name='l5kit.maps.TrafficControlElement.roundabout_directional_sign', index=48,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roundabout_other_sign', full_name='l5kit.maps.TrafficControlElement.roundabout_other_sign', index=49,
      number=60, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_left_turn_on_red_sign', full_name='l5kit.maps.TrafficControlElement.no_left_turn_on_red_sign', index=50,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_right_turn_on_red_sign', full_name='l5kit.maps.TrafficControlElement.no_right_turn_on_red_sign', index=51,
      number=62, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_turn_on_red_sign', full_name='l5kit.maps.TrafficControlElement.no_turn_on_red_sign', index=52,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='do_not_enter_sign', full_name='l5kit.maps.TrafficControlElement.do_not_enter_sign', index=53,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_u_turn_sign', full_name='l5kit.maps.TrafficControlElement.no_u_turn_sign', index=54,
      number=65, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_left_and_u_turn_sign', full_name='l5kit.maps.TrafficControlElement.no_left_and_u_turn_sign', index=55,
      number=66, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_straight_through_sign', full_name='l5kit.maps.TrafficControlElement.no_straight_through_sign', index=56,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_turn_only_sign', full_name='l5kit.maps.TrafficControlElement.left_turn_only_sign', index=57,
      number=68, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_turn_only_sign', full_name='l5kit.maps.TrafficControlElement.right_turn_only_sign', index=58,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='u_turn_only_sign', full_name='l5kit.maps.TrafficControlElement.u_turn_only_sign', index=59,
      number=70, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='straight_through_only_sign', full_name='l5kit.maps.TrafficControlElement.straight_through_only_sign', index=60,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_turn_restriction_sign', full_name='l5kit.maps.TrafficControlElement.other_turn_restriction_sign', index=61,
      number=72, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='construction_zone_sign', full_name='l5kit.maps.TrafficControlElement.construction_zone_sign', index=62,
      number=73, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_frame', full_name='l5kit.maps.TrafficControlElement.geo_frame', index=63,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='points_x_deltas_cm', full_name='l5kit.maps.TrafficControlElement.points_x_deltas_cm', index=64,
      number=3, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='points_y_deltas_cm', full_name='l5kit.maps.TrafficControlElement.points_y_deltas_cm', index=65,
      number=4, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='points_z_deltas_cm', full_name='l5kit.maps.TrafficControlElement.points_z_deltas_cm', index=66,
      number=5, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geometry_type', full_name='l5kit.maps.TrafficControlElement.geometry_type', index=67,
      number=48, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controlled_paths', full_name='l5kit.maps.TrafficControlElement.controlled_paths', index=68,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRAFFICCONTROLELEMENT_PEDESTRIANCROSSWALK, _TRAFFICCONTROLELEMENT_AUXILIARYELEMENT, _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE, _TRAFFICCONTROLELEMENT_TRAFFICLIGHT, ],
  enum_types=[
    _TRAFFICCONTROLELEMENT_GEOMETRYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Type', full_name='l5kit.maps.TrafficControlElement.Type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4817,
  serialized_end=10186,
)


_SEGMENTSEQUENCE_SEGMENTWITHORIENTATION = _descriptor.Descriptor(
  name='SegmentWithOrientation',
  full_name='l5kit.maps.SegmentSequence.SegmentWithOrientation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='segment', full_name='l5kit.maps.SegmentSequence.SegmentWithOrientation.segment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='l5kit.maps.SegmentSequence.SegmentWithOrientation.orientation', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SEGMENTSEQUENCE_SEGMENTWITHORIENTATION_ORIENTATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10327,
  serialized_end=10530,
)

_SEGMENTSEQUENCE = _descriptor.Descriptor(
  name='SegmentSequence',
  full_name='l5kit.maps.SegmentSequence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='l5kit.maps.SegmentSequence.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segments', full_name='l5kit.maps.SegmentSequence.segments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SEGMENTSEQUENCE_SEGMENTWITHORIENTATION, ],
  enum_types=[
    _SEGMENTSEQUENCE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10189,
  serialized_end=10581,
)


_LANESEQUENCE = _descriptor.Descriptor(
  name='LaneSequence',
  full_name='l5kit.maps.LaneSequence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lanes', full_name='l5kit.maps.LaneSequence.lanes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10583,
  serialized_end=10634,
)


_LANESEQUENCES = _descriptor.Descriptor(
  name='LaneSequences',
  full_name='l5kit.maps.LaneSequences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_sequences', full_name='l5kit.maps.LaneSequences.lane_sequences', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10636,
  serialized_end=10701,
)


_POLYGON = _descriptor.Descriptor(
  name='Polygon',
  full_name='l5kit.maps.Polygon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shell_vertices', full_name='l5kit.maps.Polygon.shell_vertices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='holes', full_name='l5kit.maps.Polygon.holes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10703,
  serialized_end=10797,
)


_MULTIPOLYGON = _descriptor.Descriptor(
  name='MultiPolygon',
  full_name='l5kit.maps.MultiPolygon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='polygons', full_name='l5kit.maps.MultiPolygon.polygons', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10799,
  serialized_end=10852,
)


_ANNOTATEDSHAPE_BUILDING = _descriptor.Descriptor(
  name='Building',
  full_name='l5kit.maps.AnnotatedShape.Building',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='l5kit.maps.AnnotatedShape.Building.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height_meters', full_name='l5kit.maps.AnnotatedShape.Building.height_meters', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='above_ground_floors', full_name='l5kit.maps.AnnotatedShape.Building.above_ground_floors', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ANNOTATEDSHAPE_BUILDING_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11273,
  serialized_end=11564,
)

_ANNOTATEDSHAPE_REGION = _descriptor.Descriptor(
  name='Region',
  full_name='l5kit.maps.AnnotatedShape.Region',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='l5kit.maps.AnnotatedShape.Region.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11566,
  serialized_end=11590,
)

_ANNOTATEDSHAPE = _descriptor.Descriptor(
  name='AnnotatedShape',
  full_name='l5kit.maps.AnnotatedShape',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='l5kit.maps.AnnotatedShape.name', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multipolygon', full_name='l5kit.maps.AnnotatedShape.multipolygon', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='building', full_name='l5kit.maps.AnnotatedShape.building', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='l5kit.maps.AnnotatedShape.region', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='venue', full_name='l5kit.maps.AnnotatedShape.venue', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='administrative_boundary', full_name='l5kit.maps.AnnotatedShape.administrative_boundary', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='park', full_name='l5kit.maps.AnnotatedShape.park', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drivable_surface_prior', full_name='l5kit.maps.AnnotatedShape.drivable_surface_prior', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ANNOTATEDSHAPE_BUILDING, _ANNOTATEDSHAPE_REGION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Type', full_name='l5kit.maps.AnnotatedShape.Type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10855,
  serialized_end=11598,
)


_LATLNGBOX = _descriptor.Descriptor(
  name='LatLngBox',
  full_name='l5kit.maps.LatLngBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='south_west', full_name='l5kit.maps.LatLngBox.south_west', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='north_east', full_name='l5kit.maps.LatLngBox.north_east', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11600,
  serialized_end=11701,
)


_MAPELEMENT_ELEMENT = _descriptor.Descriptor(
  name='Element',
  full_name='l5kit.maps.MapElement.Element',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='segment', full_name='l5kit.maps.MapElement.Element.segment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node', full_name='l5kit.maps.MapElement.Element.node', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane', full_name='l5kit.maps.MapElement.Element.lane', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_control_element', full_name='l5kit.maps.MapElement.Element.traffic_control_element', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction', full_name='l5kit.maps.MapElement.Element.junction', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segment_sequence', full_name='l5kit.maps.MapElement.Element.segment_sequence', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annotated_shape', full_name='l5kit.maps.MapElement.Element.annotated_shape', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='element', full_name='l5kit.maps.MapElement.Element.element',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=11923,
  serialized_end=12297,
)

_MAPELEMENT_ASSOCIATEDCONDITIONS = _descriptor.Descriptor(
  name='AssociatedConditions',
  full_name='l5kit.maps.MapElement.AssociatedConditions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='conditions', full_name='l5kit.maps.MapElement.AssociatedConditions.conditions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overrides', full_name='l5kit.maps.MapElement.AssociatedConditions.overrides', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12299,
  serialized_end=12415,
)

_MAPELEMENT = _descriptor.Descriptor(
  name='MapElement',
  full_name='l5kit.maps.MapElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='l5kit.maps.MapElement.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='element', full_name='l5kit.maps.MapElement.element', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bounding_box', full_name='l5kit.maps.MapElement.bounding_box', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='associated_conditions', full_name='l5kit.maps.MapElement.associated_conditions', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MAPELEMENT_ELEMENT, _MAPELEMENT_ASSOCIATEDCONDITIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11704,
  serialized_end=12415,
)


_MAPFRAGMENT = _descriptor.Descriptor(
  name='MapFragment',
  full_name='l5kit.maps.MapFragment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='l5kit.maps.MapFragment.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elements', full_name='l5kit.maps.MapFragment.elements', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12417,
  serialized_end=12486,
)

_GEOLOCATION.oneofs_by_name['Altitude'].fields.append(
  _GEOLOCATION.fields_by_name['altitude_cm'])
_GEOLOCATION.fields_by_name['altitude_cm'].containing_oneof = _GEOLOCATION.oneofs_by_name['Altitude']
_GEOFRAME.fields_by_name['origin'].message_type = _GEOLOCATION
_ROADNETWORKNODE.fields_by_name['location'].message_type = _GEOLOCATION
_ROADNETWORKNODE.fields_by_name['road_segments'].message_type = _GLOBALID
_ROADNETWORKNODE.fields_by_name['junction'].message_type = _GLOBALID
_ACCESSRESTRICTION.fields_by_name['type'].enum_type = _ACCESSRESTRICTION_TYPE
_ACCESSRESTRICTION_TYPE.containing_type = _ACCESSRESTRICTION
_DAILYTIMEINTERVAL.fields_by_name['day_of_the_week'].enum_type = _DAILYTIMEINTERVAL_DAYOFTHEWEEK
_DAILYTIMEINTERVAL_DAYOFTHEWEEK.containing_type = _DAILYTIMEINTERVAL
_SCHEDULE.fields_by_name['daily_schedule'].message_type = _DAILYTIMEINTERVAL
_CONDITION.fields_by_name['daily_temporal_condition'].message_type = _DAILYTIMEINTERVAL
_CONDITION.oneofs_by_name['condition'].fields.append(
  _CONDITION.fields_by_name['daily_temporal_condition'])
_CONDITION.fields_by_name['daily_temporal_condition'].containing_oneof = _CONDITION.oneofs_by_name['condition']
_ROADNETWORKSEGMENT_LANESET.fields_by_name['bike_lane_access'].enum_type = _ROADNETWORKSEGMENT_LANESET_BIKELANEACCESS
_ROADNETWORKSEGMENT_LANESET.containing_type = _ROADNETWORKSEGMENT
_ROADNETWORKSEGMENT_LANESET_BIKELANEACCESS.containing_type = _ROADNETWORKSEGMENT_LANESET
_ROADNETWORKSEGMENT.fields_by_name['vertices'].message_type = _GEOLOCATION
_ROADNETWORKSEGMENT.fields_by_name['start_node'].message_type = _GLOBALID
_ROADNETWORKSEGMENT.fields_by_name['end_node'].message_type = _GLOBALID
_ROADNETWORKSEGMENT.fields_by_name['forward_lane_set'].message_type = _ROADNETWORKSEGMENT_LANESET
_ROADNETWORKSEGMENT.fields_by_name['backward_lane_set'].message_type = _ROADNETWORKSEGMENT_LANESET
_ROADNETWORKSEGMENT.fields_by_name['lanes'].message_type = _GLOBALID
_ROADNETWORKSEGMENT.fields_by_name['name'].message_type = _LOCALIZEDSTRING
_ROADNETWORKSEGMENT.fields_by_name['road_class'].enum_type = _ROADNETWORKSEGMENT_ROADCLASS
_ROADNETWORKSEGMENT.fields_by_name['travel_direction'].enum_type = _ROADNETWORKSEGMENT_TRAVELDIRECTION
_ROADNETWORKSEGMENT.fields_by_name['restrictions'].message_type = _GLOBALID
_ROADNETWORKSEGMENT.fields_by_name['walkable'].enum_type = _ROADNETWORKSEGMENT_SIDEOFSEGMENT
_ROADNETWORKSEGMENT.fields_by_name['forward_bikeable'].enum_type = _ROADNETWORKSEGMENT_BIKEACCESS
_ROADNETWORKSEGMENT.fields_by_name['backward_bikeable'].enum_type = _ROADNETWORKSEGMENT_BIKEACCESS
_ROADNETWORKSEGMENT_ROADCLASS.containing_type = _ROADNETWORKSEGMENT
_ROADNETWORKSEGMENT_TRAVELDIRECTION.containing_type = _ROADNETWORKSEGMENT
_ROADNETWORKSEGMENT_SIDEOFSEGMENT.containing_type = _ROADNETWORKSEGMENT
_ROADNETWORKSEGMENT_BIKEACCESS.containing_type = _ROADNETWORKSEGMENT
_JUNCTION.fields_by_name['road_network_nodes'].message_type = _GLOBALID
_JUNCTION.fields_by_name['lanes'].message_type = _GLOBALID
_JUNCTION.fields_by_name['traffic_control_elements'].message_type = _GLOBALID
_LANE_BOUNDARY.fields_by_name['divider_type'].enum_type = _LANE_BOUNDARY_DIVIDERTYPE
_LANE_BOUNDARY.containing_type = _LANE
_LANE_BOUNDARY_DIVIDERTYPE.containing_type = _LANE_BOUNDARY
_LANE.fields_by_name['parent_segment_or_junction'].message_type = _GLOBALID
_LANE.fields_by_name['access_restriction'].message_type = _ACCESSRESTRICTION
_LANE.fields_by_name['orientation_in_parent_segment'].enum_type = _ROADNETWORKSEGMENT_TRAVELDIRECTION
_LANE.fields_by_name['turn_type_in_parent_junction'].enum_type = _LANE_TURNTYPE
_LANE.fields_by_name['geo_frame'].message_type = _GEOFRAME
_LANE.fields_by_name['left_boundary'].message_type = _LANE_BOUNDARY
_LANE.fields_by_name['right_boundary'].message_type = _LANE_BOUNDARY
_LANE.fields_by_name['lanes_ahead'].message_type = _GLOBALID
_LANE.fields_by_name['adjacent_lane_change_left'].message_type = _GLOBALID
_LANE.fields_by_name['adjacent_lane_change_right'].message_type = _GLOBALID
_LANE.fields_by_name['traffic_controls'].message_type = _GLOBALID
_LANE.fields_by_name['yield_to_lanes'].message_type = _GLOBALID
_LANE.fields_by_name['tolls'].message_type = _GLOBALID
_LANE_TURNTYPE.containing_type = _LANE
_TRAFFICCONTROLELEMENT_PEDESTRIANCROSSWALK.fields_by_name['traffic_lights'].message_type = _GLOBALID
_TRAFFICCONTROLELEMENT_PEDESTRIANCROSSWALK.fields_by_name['yield_lines'].message_type = _GLOBALID
_TRAFFICCONTROLELEMENT_PEDESTRIANCROSSWALK.containing_type = _TRAFFICCONTROLELEMENT
_TRAFFICCONTROLELEMENT_AUXILIARYELEMENT.fields_by_name['primary_traffic_control_elements'].message_type = _GLOBALID
_TRAFFICCONTROLELEMENT_AUXILIARYELEMENT.containing_type = _TRAFFICCONTROLELEMENT
_TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE_YIELDSET.fields_by_name['lane'].message_type = _GLOBALID
_TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE_YIELDSET.fields_by_name['yield_to_lanes'].message_type = _GLOBALID
_TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE_YIELDSET.fields_by_name['yield_to_crosswalks'].message_type = _GLOBALID
_TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE_YIELDSET.containing_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE.fields_by_name['yield_rules_when_on'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE_YIELDSET
_TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE.containing_type = _TRAFFICCONTROLELEMENT
_TRAFFICCONTROLELEMENT_TRAFFICLIGHT.fields_by_name['face_states'].message_type = _GLOBALID
_TRAFFICCONTROLELEMENT_TRAFFICLIGHT.containing_type = _TRAFFICCONTROLELEMENT
_TRAFFICCONTROLELEMENT.fields_by_name['stop_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['yield_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['stop_line'].message_type = _TRAFFICCONTROLELEMENT_AUXILIARYELEMENT
_TRAFFICCONTROLELEMENT.fields_by_name['traffic_light'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHT
_TRAFFICCONTROLELEMENT.fields_by_name['signal_flashing_yellow'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_flashing_red'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_red_face'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_yellow_face'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_green_face'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_left_arrow_red_face'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_left_arrow_yellow_face'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_left_arrow_green_face'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_right_arrow_red_face'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_right_arrow_yellow_face'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_right_arrow_green_face'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_left_arrow_red_face'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_left_arrow_yellow_face'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_left_arrow_green_face'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_right_arrow_red_face'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_right_arrow_yellow_face'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_right_arrow_green_face'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_red_u_turn'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_yellow_u_turn'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['signal_green_u_turn'].message_type = _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE
_TRAFFICCONTROLELEMENT.fields_by_name['speed_bump'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['speed_hump'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['pedestrian_crosswalk'].message_type = _TRAFFICCONTROLELEMENT_PEDESTRIANCROSSWALK
_TRAFFICCONTROLELEMENT.fields_by_name['keep_clear_zone'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['pedestrian_crossing_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['signal_ahead_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['no_left_turn_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['no_right_turn_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['left_turn_yield_on_green_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['no_parking_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['one_way_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['school_zone_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['parking_zone'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['speed_bump_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['construction_zone'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['stop_here_for_pedestrians_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['state_law_stop_for_pedestrian_in_crosswalk_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['yield_here_for_pedestrians_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['turning_vehicles_yield_to_pedestrians_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['state_law_yield_for_pedestrian_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['railroad_crossing_regulatory_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['railroad_crossing_warning_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['railroad_crossing_other_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['roundabout_circulation_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['roundabout_directional_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['roundabout_other_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['no_left_turn_on_red_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['no_right_turn_on_red_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['no_turn_on_red_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['do_not_enter_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['no_u_turn_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['no_left_and_u_turn_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['no_straight_through_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['left_turn_only_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['right_turn_only_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['u_turn_only_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['straight_through_only_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['other_turn_restriction_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['construction_zone_sign'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TRAFFICCONTROLELEMENT.fields_by_name['geo_frame'].message_type = _GEOFRAME
_TRAFFICCONTROLELEMENT.fields_by_name['geometry_type'].enum_type = _TRAFFICCONTROLELEMENT_GEOMETRYTYPE
_TRAFFICCONTROLELEMENT.fields_by_name['controlled_paths'].message_type = _LANESEQUENCE
_TRAFFICCONTROLELEMENT_GEOMETRYTYPE.containing_type = _TRAFFICCONTROLELEMENT
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['stop_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['stop_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['yield_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['yield_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['stop_line'])
_TRAFFICCONTROLELEMENT.fields_by_name['stop_line'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['traffic_light'])
_TRAFFICCONTROLELEMENT.fields_by_name['traffic_light'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_flashing_yellow'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_flashing_yellow'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_flashing_red'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_flashing_red'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_red_face'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_red_face'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_yellow_face'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_yellow_face'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_green_face'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_green_face'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_left_arrow_red_face'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_left_arrow_red_face'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_left_arrow_yellow_face'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_left_arrow_yellow_face'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_left_arrow_green_face'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_left_arrow_green_face'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_right_arrow_red_face'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_right_arrow_red_face'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_right_arrow_yellow_face'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_right_arrow_yellow_face'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_right_arrow_green_face'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_right_arrow_green_face'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_left_arrow_red_face'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_left_arrow_red_face'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_left_arrow_yellow_face'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_left_arrow_yellow_face'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_left_arrow_green_face'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_left_arrow_green_face'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_right_arrow_red_face'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_right_arrow_red_face'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_right_arrow_yellow_face'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_right_arrow_yellow_face'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_right_arrow_green_face'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_upper_right_arrow_green_face'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_red_u_turn'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_red_u_turn'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_yellow_u_turn'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_yellow_u_turn'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_green_u_turn'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_green_u_turn'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['speed_bump'])
_TRAFFICCONTROLELEMENT.fields_by_name['speed_bump'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['speed_hump'])
_TRAFFICCONTROLELEMENT.fields_by_name['speed_hump'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['pedestrian_crosswalk'])
_TRAFFICCONTROLELEMENT.fields_by_name['pedestrian_crosswalk'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['keep_clear_zone'])
_TRAFFICCONTROLELEMENT.fields_by_name['keep_clear_zone'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['pedestrian_crossing_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['pedestrian_crossing_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['signal_ahead_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['signal_ahead_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['no_left_turn_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['no_left_turn_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['no_right_turn_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['no_right_turn_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['left_turn_yield_on_green_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['left_turn_yield_on_green_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['no_parking_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['no_parking_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['one_way_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['one_way_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['school_zone_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['school_zone_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['parking_zone'])
_TRAFFICCONTROLELEMENT.fields_by_name['parking_zone'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['speed_bump_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['speed_bump_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['construction_zone'])
_TRAFFICCONTROLELEMENT.fields_by_name['construction_zone'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['stop_here_for_pedestrians_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['stop_here_for_pedestrians_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['state_law_stop_for_pedestrian_in_crosswalk_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['state_law_stop_for_pedestrian_in_crosswalk_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['yield_here_for_pedestrians_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['yield_here_for_pedestrians_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['turning_vehicles_yield_to_pedestrians_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['turning_vehicles_yield_to_pedestrians_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['state_law_yield_for_pedestrian_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['state_law_yield_for_pedestrian_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['railroad_crossing_regulatory_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['railroad_crossing_regulatory_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['railroad_crossing_warning_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['railroad_crossing_warning_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['railroad_crossing_other_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['railroad_crossing_other_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['roundabout_circulation_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['roundabout_circulation_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['roundabout_directional_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['roundabout_directional_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['roundabout_other_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['roundabout_other_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['no_left_turn_on_red_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['no_left_turn_on_red_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['no_right_turn_on_red_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['no_right_turn_on_red_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['no_turn_on_red_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['no_turn_on_red_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['do_not_enter_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['do_not_enter_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['no_u_turn_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['no_u_turn_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['no_left_and_u_turn_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['no_left_and_u_turn_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['no_straight_through_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['no_straight_through_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['left_turn_only_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['left_turn_only_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['right_turn_only_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['right_turn_only_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['u_turn_only_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['u_turn_only_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['straight_through_only_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['straight_through_only_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['other_turn_restriction_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['other_turn_restriction_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_TRAFFICCONTROLELEMENT.oneofs_by_name['Type'].fields.append(
  _TRAFFICCONTROLELEMENT.fields_by_name['construction_zone_sign'])
_TRAFFICCONTROLELEMENT.fields_by_name['construction_zone_sign'].containing_oneof = _TRAFFICCONTROLELEMENT.oneofs_by_name['Type']
_SEGMENTSEQUENCE_SEGMENTWITHORIENTATION.fields_by_name['segment'].message_type = _GLOBALID
_SEGMENTSEQUENCE_SEGMENTWITHORIENTATION.fields_by_name['orientation'].enum_type = _SEGMENTSEQUENCE_SEGMENTWITHORIENTATION_ORIENTATION
_SEGMENTSEQUENCE_SEGMENTWITHORIENTATION.containing_type = _SEGMENTSEQUENCE
_SEGMENTSEQUENCE_SEGMENTWITHORIENTATION_ORIENTATION.containing_type = _SEGMENTSEQUENCE_SEGMENTWITHORIENTATION
_SEGMENTSEQUENCE.fields_by_name['type'].enum_type = _SEGMENTSEQUENCE_TYPE
_SEGMENTSEQUENCE.fields_by_name['segments'].message_type = _SEGMENTSEQUENCE_SEGMENTWITHORIENTATION
_SEGMENTSEQUENCE_TYPE.containing_type = _SEGMENTSEQUENCE
_LANESEQUENCE.fields_by_name['lanes'].message_type = _GLOBALID
_LANESEQUENCES.fields_by_name['lane_sequences'].message_type = _LANESEQUENCE
_POLYGON.fields_by_name['shell_vertices'].message_type = _GEOLOCATION
_POLYGON.fields_by_name['holes'].message_type = _POLYGON
_MULTIPOLYGON.fields_by_name['polygons'].message_type = _POLYGON
_ANNOTATEDSHAPE_BUILDING.fields_by_name['type'].enum_type = _ANNOTATEDSHAPE_BUILDING_TYPE
_ANNOTATEDSHAPE_BUILDING.containing_type = _ANNOTATEDSHAPE
_ANNOTATEDSHAPE_BUILDING_TYPE.containing_type = _ANNOTATEDSHAPE_BUILDING
_ANNOTATEDSHAPE_REGION.containing_type = _ANNOTATEDSHAPE
_ANNOTATEDSHAPE.fields_by_name['name'].message_type = _LOCALIZEDSTRING
_ANNOTATEDSHAPE.fields_by_name['multipolygon'].message_type = _MULTIPOLYGON
_ANNOTATEDSHAPE.fields_by_name['building'].message_type = _ANNOTATEDSHAPE_BUILDING
_ANNOTATEDSHAPE.fields_by_name['region'].message_type = _ANNOTATEDSHAPE_REGION
_ANNOTATEDSHAPE.fields_by_name['venue'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_ANNOTATEDSHAPE.fields_by_name['administrative_boundary'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_ANNOTATEDSHAPE.fields_by_name['park'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_ANNOTATEDSHAPE.fields_by_name['drivable_surface_prior'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_ANNOTATEDSHAPE.oneofs_by_name['Type'].fields.append(
  _ANNOTATEDSHAPE.fields_by_name['building'])
_ANNOTATEDSHAPE.fields_by_name['building'].containing_oneof = _ANNOTATEDSHAPE.oneofs_by_name['Type']
_ANNOTATEDSHAPE.oneofs_by_name['Type'].fields.append(
  _ANNOTATEDSHAPE.fields_by_name['region'])
_ANNOTATEDSHAPE.fields_by_name['region'].containing_oneof = _ANNOTATEDSHAPE.oneofs_by_name['Type']
_ANNOTATEDSHAPE.oneofs_by_name['Type'].fields.append(
  _ANNOTATEDSHAPE.fields_by_name['venue'])
_ANNOTATEDSHAPE.fields_by_name['venue'].containing_oneof = _ANNOTATEDSHAPE.oneofs_by_name['Type']
_ANNOTATEDSHAPE.oneofs_by_name['Type'].fields.append(
  _ANNOTATEDSHAPE.fields_by_name['administrative_boundary'])
_ANNOTATEDSHAPE.fields_by_name['administrative_boundary'].containing_oneof = _ANNOTATEDSHAPE.oneofs_by_name['Type']
_ANNOTATEDSHAPE.oneofs_by_name['Type'].fields.append(
  _ANNOTATEDSHAPE.fields_by_name['park'])
_ANNOTATEDSHAPE.fields_by_name['park'].containing_oneof = _ANNOTATEDSHAPE.oneofs_by_name['Type']
_ANNOTATEDSHAPE.oneofs_by_name['Type'].fields.append(
  _ANNOTATEDSHAPE.fields_by_name['drivable_surface_prior'])
_ANNOTATEDSHAPE.fields_by_name['drivable_surface_prior'].containing_oneof = _ANNOTATEDSHAPE.oneofs_by_name['Type']
_LATLNGBOX.fields_by_name['south_west'].message_type = _GEOLOCATION
_LATLNGBOX.fields_by_name['north_east'].message_type = _GEOLOCATION
_MAPELEMENT_ELEMENT.fields_by_name['segment'].message_type = _ROADNETWORKSEGMENT
_MAPELEMENT_ELEMENT.fields_by_name['node'].message_type = _ROADNETWORKNODE
_MAPELEMENT_ELEMENT.fields_by_name['lane'].message_type = _LANE
_MAPELEMENT_ELEMENT.fields_by_name['traffic_control_element'].message_type = _TRAFFICCONTROLELEMENT
_MAPELEMENT_ELEMENT.fields_by_name['junction'].message_type = _JUNCTION
_MAPELEMENT_ELEMENT.fields_by_name['segment_sequence'].message_type = _SEGMENTSEQUENCE
_MAPELEMENT_ELEMENT.fields_by_name['annotated_shape'].message_type = _ANNOTATEDSHAPE
_MAPELEMENT_ELEMENT.containing_type = _MAPELEMENT
_MAPELEMENT_ELEMENT.oneofs_by_name['element'].fields.append(
  _MAPELEMENT_ELEMENT.fields_by_name['segment'])
_MAPELEMENT_ELEMENT.fields_by_name['segment'].containing_oneof = _MAPELEMENT_ELEMENT.oneofs_by_name['element']
_MAPELEMENT_ELEMENT.oneofs_by_name['element'].fields.append(
  _MAPELEMENT_ELEMENT.fields_by_name['node'])
_MAPELEMENT_ELEMENT.fields_by_name['node'].containing_oneof = _MAPELEMENT_ELEMENT.oneofs_by_name['element']
_MAPELEMENT_ELEMENT.oneofs_by_name['element'].fields.append(
  _MAPELEMENT_ELEMENT.fields_by_name['lane'])
_MAPELEMENT_ELEMENT.fields_by_name['lane'].containing_oneof = _MAPELEMENT_ELEMENT.oneofs_by_name['element']
_MAPELEMENT_ELEMENT.oneofs_by_name['element'].fields.append(
  _MAPELEMENT_ELEMENT.fields_by_name['traffic_control_element'])
_MAPELEMENT_ELEMENT.fields_by_name['traffic_control_element'].containing_oneof = _MAPELEMENT_ELEMENT.oneofs_by_name['element']
_MAPELEMENT_ELEMENT.oneofs_by_name['element'].fields.append(
  _MAPELEMENT_ELEMENT.fields_by_name['junction'])
_MAPELEMENT_ELEMENT.fields_by_name['junction'].containing_oneof = _MAPELEMENT_ELEMENT.oneofs_by_name['element']
_MAPELEMENT_ELEMENT.oneofs_by_name['element'].fields.append(
  _MAPELEMENT_ELEMENT.fields_by_name['segment_sequence'])
_MAPELEMENT_ELEMENT.fields_by_name['segment_sequence'].containing_oneof = _MAPELEMENT_ELEMENT.oneofs_by_name['element']
_MAPELEMENT_ELEMENT.oneofs_by_name['element'].fields.append(
  _MAPELEMENT_ELEMENT.fields_by_name['annotated_shape'])
_MAPELEMENT_ELEMENT.fields_by_name['annotated_shape'].containing_oneof = _MAPELEMENT_ELEMENT.oneofs_by_name['element']
_MAPELEMENT_ASSOCIATEDCONDITIONS.fields_by_name['conditions'].message_type = _CONDITION
_MAPELEMENT_ASSOCIATEDCONDITIONS.fields_by_name['overrides'].message_type = _MAPELEMENT_ELEMENT
_MAPELEMENT_ASSOCIATEDCONDITIONS.containing_type = _MAPELEMENT
_MAPELEMENT.fields_by_name['id'].message_type = _GLOBALID
_MAPELEMENT.fields_by_name['element'].message_type = _MAPELEMENT_ELEMENT
_MAPELEMENT.fields_by_name['bounding_box'].message_type = _LATLNGBOX
_MAPELEMENT.fields_by_name['associated_conditions'].message_type = _MAPELEMENT_ASSOCIATEDCONDITIONS
_MAPFRAGMENT.fields_by_name['elements'].message_type = _MAPELEMENT
DESCRIPTOR.message_types_by_name['GlobalId'] = _GLOBALID
DESCRIPTOR.message_types_by_name['GeoLocation'] = _GEOLOCATION
DESCRIPTOR.message_types_by_name['GeoFrame'] = _GEOFRAME
DESCRIPTOR.message_types_by_name['LocalizedString'] = _LOCALIZEDSTRING
DESCRIPTOR.message_types_by_name['RoadNetworkNode'] = _ROADNETWORKNODE
DESCRIPTOR.message_types_by_name['AccessRestriction'] = _ACCESSRESTRICTION
DESCRIPTOR.message_types_by_name['DailyTimeInterval'] = _DAILYTIMEINTERVAL
DESCRIPTOR.message_types_by_name['Schedule'] = _SCHEDULE
DESCRIPTOR.message_types_by_name['Condition'] = _CONDITION
DESCRIPTOR.message_types_by_name['RoadNetworkSegment'] = _ROADNETWORKSEGMENT
DESCRIPTOR.message_types_by_name['Junction'] = _JUNCTION
DESCRIPTOR.message_types_by_name['Lane'] = _LANE
DESCRIPTOR.message_types_by_name['TrafficControlElement'] = _TRAFFICCONTROLELEMENT
DESCRIPTOR.message_types_by_name['SegmentSequence'] = _SEGMENTSEQUENCE
DESCRIPTOR.message_types_by_name['LaneSequence'] = _LANESEQUENCE
DESCRIPTOR.message_types_by_name['LaneSequences'] = _LANESEQUENCES
DESCRIPTOR.message_types_by_name['Polygon'] = _POLYGON
DESCRIPTOR.message_types_by_name['MultiPolygon'] = _MULTIPOLYGON
DESCRIPTOR.message_types_by_name['AnnotatedShape'] = _ANNOTATEDSHAPE
DESCRIPTOR.message_types_by_name['LatLngBox'] = _LATLNGBOX
DESCRIPTOR.message_types_by_name['MapElement'] = _MAPELEMENT
DESCRIPTOR.message_types_by_name['MapFragment'] = _MAPFRAGMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GlobalId = _reflection.GeneratedProtocolMessageType('GlobalId', (_message.Message,), {
  'DESCRIPTOR' : _GLOBALID,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.GlobalId)
  })
_sym_db.RegisterMessage(GlobalId)

GeoLocation = _reflection.GeneratedProtocolMessageType('GeoLocation', (_message.Message,), {
  'DESCRIPTOR' : _GEOLOCATION,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.GeoLocation)
  })
_sym_db.RegisterMessage(GeoLocation)

GeoFrame = _reflection.GeneratedProtocolMessageType('GeoFrame', (_message.Message,), {
  'DESCRIPTOR' : _GEOFRAME,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.GeoFrame)
  })
_sym_db.RegisterMessage(GeoFrame)

LocalizedString = _reflection.GeneratedProtocolMessageType('LocalizedString', (_message.Message,), {
  'DESCRIPTOR' : _LOCALIZEDSTRING,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.LocalizedString)
  })
_sym_db.RegisterMessage(LocalizedString)

RoadNetworkNode = _reflection.GeneratedProtocolMessageType('RoadNetworkNode', (_message.Message,), {
  'DESCRIPTOR' : _ROADNETWORKNODE,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.RoadNetworkNode)
  })
_sym_db.RegisterMessage(RoadNetworkNode)

AccessRestriction = _reflection.GeneratedProtocolMessageType('AccessRestriction', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSRESTRICTION,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.AccessRestriction)
  })
_sym_db.RegisterMessage(AccessRestriction)

DailyTimeInterval = _reflection.GeneratedProtocolMessageType('DailyTimeInterval', (_message.Message,), {
  'DESCRIPTOR' : _DAILYTIMEINTERVAL,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.DailyTimeInterval)
  })
_sym_db.RegisterMessage(DailyTimeInterval)

Schedule = _reflection.GeneratedProtocolMessageType('Schedule', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULE,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.Schedule)
  })
_sym_db.RegisterMessage(Schedule)

Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {
  'DESCRIPTOR' : _CONDITION,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.Condition)
  })
_sym_db.RegisterMessage(Condition)

RoadNetworkSegment = _reflection.GeneratedProtocolMessageType('RoadNetworkSegment', (_message.Message,), {

  'LaneSet' : _reflection.GeneratedProtocolMessageType('LaneSet', (_message.Message,), {
    'DESCRIPTOR' : _ROADNETWORKSEGMENT_LANESET,
    '__module__' : 'road_network_pb2'
    # @@protoc_insertion_point(class_scope:l5kit.maps.RoadNetworkSegment.LaneSet)
    })
  ,
  'DESCRIPTOR' : _ROADNETWORKSEGMENT,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.RoadNetworkSegment)
  })
_sym_db.RegisterMessage(RoadNetworkSegment)
_sym_db.RegisterMessage(RoadNetworkSegment.LaneSet)

Junction = _reflection.GeneratedProtocolMessageType('Junction', (_message.Message,), {
  'DESCRIPTOR' : _JUNCTION,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.Junction)
  })
_sym_db.RegisterMessage(Junction)

Lane = _reflection.GeneratedProtocolMessageType('Lane', (_message.Message,), {

  'Boundary' : _reflection.GeneratedProtocolMessageType('Boundary', (_message.Message,), {
    'DESCRIPTOR' : _LANE_BOUNDARY,
    '__module__' : 'road_network_pb2'
    # @@protoc_insertion_point(class_scope:l5kit.maps.Lane.Boundary)
    })
  ,
  'DESCRIPTOR' : _LANE,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.Lane)
  })
_sym_db.RegisterMessage(Lane)
_sym_db.RegisterMessage(Lane.Boundary)

TrafficControlElement = _reflection.GeneratedProtocolMessageType('TrafficControlElement', (_message.Message,), {

  'PedestrianCrosswalk' : _reflection.GeneratedProtocolMessageType('PedestrianCrosswalk', (_message.Message,), {
    'DESCRIPTOR' : _TRAFFICCONTROLELEMENT_PEDESTRIANCROSSWALK,
    '__module__' : 'road_network_pb2'
    # @@protoc_insertion_point(class_scope:l5kit.maps.TrafficControlElement.PedestrianCrosswalk)
    })
  ,

  'AuxiliaryElement' : _reflection.GeneratedProtocolMessageType('AuxiliaryElement', (_message.Message,), {
    'DESCRIPTOR' : _TRAFFICCONTROLELEMENT_AUXILIARYELEMENT,
    '__module__' : 'road_network_pb2'
    # @@protoc_insertion_point(class_scope:l5kit.maps.TrafficControlElement.AuxiliaryElement)
    })
  ,

  'TrafficLightFaceState' : _reflection.GeneratedProtocolMessageType('TrafficLightFaceState', (_message.Message,), {

    'YieldSet' : _reflection.GeneratedProtocolMessageType('YieldSet', (_message.Message,), {
      'DESCRIPTOR' : _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE_YIELDSET,
      '__module__' : 'road_network_pb2'
      # @@protoc_insertion_point(class_scope:l5kit.maps.TrafficControlElement.TrafficLightFaceState.YieldSet)
      })
    ,
    'DESCRIPTOR' : _TRAFFICCONTROLELEMENT_TRAFFICLIGHTFACESTATE,
    '__module__' : 'road_network_pb2'
    # @@protoc_insertion_point(class_scope:l5kit.maps.TrafficControlElement.TrafficLightFaceState)
    })
  ,

  'TrafficLight' : _reflection.GeneratedProtocolMessageType('TrafficLight', (_message.Message,), {
    'DESCRIPTOR' : _TRAFFICCONTROLELEMENT_TRAFFICLIGHT,
    '__module__' : 'road_network_pb2'
    # @@protoc_insertion_point(class_scope:l5kit.maps.TrafficControlElement.TrafficLight)
    })
  ,
  'DESCRIPTOR' : _TRAFFICCONTROLELEMENT,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.TrafficControlElement)
  })
_sym_db.RegisterMessage(TrafficControlElement)
_sym_db.RegisterMessage(TrafficControlElement.PedestrianCrosswalk)
_sym_db.RegisterMessage(TrafficControlElement.AuxiliaryElement)
_sym_db.RegisterMessage(TrafficControlElement.TrafficLightFaceState)
_sym_db.RegisterMessage(TrafficControlElement.TrafficLightFaceState.YieldSet)
_sym_db.RegisterMessage(TrafficControlElement.TrafficLight)

SegmentSequence = _reflection.GeneratedProtocolMessageType('SegmentSequence', (_message.Message,), {

  'SegmentWithOrientation' : _reflection.GeneratedProtocolMessageType('SegmentWithOrientation', (_message.Message,), {
    'DESCRIPTOR' : _SEGMENTSEQUENCE_SEGMENTWITHORIENTATION,
    '__module__' : 'road_network_pb2'
    # @@protoc_insertion_point(class_scope:l5kit.maps.SegmentSequence.SegmentWithOrientation)
    })
  ,
  'DESCRIPTOR' : _SEGMENTSEQUENCE,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.SegmentSequence)
  })
_sym_db.RegisterMessage(SegmentSequence)
_sym_db.RegisterMessage(SegmentSequence.SegmentWithOrientation)

LaneSequence = _reflection.GeneratedProtocolMessageType('LaneSequence', (_message.Message,), {
  'DESCRIPTOR' : _LANESEQUENCE,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.LaneSequence)
  })
_sym_db.RegisterMessage(LaneSequence)

LaneSequences = _reflection.GeneratedProtocolMessageType('LaneSequences', (_message.Message,), {
  'DESCRIPTOR' : _LANESEQUENCES,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.LaneSequences)
  })
_sym_db.RegisterMessage(LaneSequences)

Polygon = _reflection.GeneratedProtocolMessageType('Polygon', (_message.Message,), {
  'DESCRIPTOR' : _POLYGON,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.Polygon)
  })
_sym_db.RegisterMessage(Polygon)

MultiPolygon = _reflection.GeneratedProtocolMessageType('MultiPolygon', (_message.Message,), {
  'DESCRIPTOR' : _MULTIPOLYGON,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.MultiPolygon)
  })
_sym_db.RegisterMessage(MultiPolygon)

AnnotatedShape = _reflection.GeneratedProtocolMessageType('AnnotatedShape', (_message.Message,), {

  'Building' : _reflection.GeneratedProtocolMessageType('Building', (_message.Message,), {
    'DESCRIPTOR' : _ANNOTATEDSHAPE_BUILDING,
    '__module__' : 'road_network_pb2'
    # @@protoc_insertion_point(class_scope:l5kit.maps.AnnotatedShape.Building)
    })
  ,

  'Region' : _reflection.GeneratedProtocolMessageType('Region', (_message.Message,), {
    'DESCRIPTOR' : _ANNOTATEDSHAPE_REGION,
    '__module__' : 'road_network_pb2'
    # @@protoc_insertion_point(class_scope:l5kit.maps.AnnotatedShape.Region)
    })
  ,
  'DESCRIPTOR' : _ANNOTATEDSHAPE,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.AnnotatedShape)
  })
_sym_db.RegisterMessage(AnnotatedShape)
_sym_db.RegisterMessage(AnnotatedShape.Building)
_sym_db.RegisterMessage(AnnotatedShape.Region)

LatLngBox = _reflection.GeneratedProtocolMessageType('LatLngBox', (_message.Message,), {
  'DESCRIPTOR' : _LATLNGBOX,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.LatLngBox)
  })
_sym_db.RegisterMessage(LatLngBox)

MapElement = _reflection.GeneratedProtocolMessageType('MapElement', (_message.Message,), {

  'Element' : _reflection.GeneratedProtocolMessageType('Element', (_message.Message,), {
    'DESCRIPTOR' : _MAPELEMENT_ELEMENT,
    '__module__' : 'road_network_pb2'
    # @@protoc_insertion_point(class_scope:l5kit.maps.MapElement.Element)
    })
  ,

  'AssociatedConditions' : _reflection.GeneratedProtocolMessageType('AssociatedConditions', (_message.Message,), {
    'DESCRIPTOR' : _MAPELEMENT_ASSOCIATEDCONDITIONS,
    '__module__' : 'road_network_pb2'
    # @@protoc_insertion_point(class_scope:l5kit.maps.MapElement.AssociatedConditions)
    })
  ,
  'DESCRIPTOR' : _MAPELEMENT,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.MapElement)
  })
_sym_db.RegisterMessage(MapElement)
_sym_db.RegisterMessage(MapElement.Element)
_sym_db.RegisterMessage(MapElement.AssociatedConditions)

MapFragment = _reflection.GeneratedProtocolMessageType('MapFragment', (_message.Message,), {
  'DESCRIPTOR' : _MAPFRAGMENT,
  '__module__' : 'road_network_pb2'
  # @@protoc_insertion_point(class_scope:l5kit.maps.MapFragment)
  })
_sym_db.RegisterMessage(MapFragment)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
